==> tuia-treasure-center-api-1.6.6.1-AD-20181219.082104-7-sources.jar: cn/tuia/tuia/treasure/center/api/dto/SlotPositionDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;

import cn.tuia.tuia.treasure.center.api.enums.SlotPositionConfig;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xuefeng on 2018/12/19.
 */
public class SlotPositionDto implements Serializable {

    private static final long serialVersionUID = 1L;

    private Long id;

    private Integer position;

    private String positionDesc;

    private Boolean stable;

    private Boolean opened;

    private Boolean wxbOpened;

    private Boolean wyylOpened;

    private Boolean wlttOpened;

    private Boolean wybdOpened;

    private Date gmtCreate;

    private Date gmtModified;

    /**
     * 广告位置配置
     */
    private SlotPositionConfig slotPositionConfig;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getPosition() {
        return position;
    }

    public void setPosition(Integer position) {
        this.position = position;
    }

    public String getPositionDesc() {
        return positionDesc;
    }

    public void setPositionDesc(String positionDesc) {
        this.positionDesc = positionDesc;
    }

    public Boolean getStable() {
        return stable;
    }

    public void setStable(Boolean stable) {
        this.stable = stable;
    }

    public Boolean getOpened() {
        return opened;
    }

    public void setOpened(Boolean opened) {
        this.opened = opened;
    }

    public Boolean getWxbOpened() {
        return wxbOpened;
    }

    public void setWxbOpened(Boolean wxbOpened) {
        this.wxbOpened = wxbOpened;
    }

    public Boolean getWyylOpened() {
        return wyylOpened;
    }

    public void setWyylOpened(Boolean wyylOpened) {
        this.wyylOpened = wyylOpened;
    }

    public Boolean getWlttOpened() {
        return wlttOpened;
    }

    public void setWlttOpened(Boolean wlttOpened) {
        this.wlttOpened = wlttOpened;
    }

    public Boolean getWybdOpened() {
        return wybdOpened;
    }

    public void setWybdOpened(Boolean wybdOpened) {
        this.wybdOpened = wybdOpened;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public SlotPositionConfig getSlotPositionConfig() {
        return slotPositionConfig;
    }

    public void setSlotPositionConfig(SlotPositionConfig slotPositionConfig) {
        this.slotPositionConfig = slotPositionConfig;
    }
}

==> tuia-treasure-center-api-1.7.0.0-AD-20181220.071434-3-sources.jar: cn/tuia/tuia/treasure/center/api/dto/SlotPositionDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;

import cn.tuia.tuia.treasure.center.api.enums.SlotPositionConfig;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xuefeng on 2018/12/19.
 */
public class SlotPositionDto implements Serializable {

    private static final long serialVersionUID = 1L;

    private Long id;

    private Integer positionCode;

    private String positionDesc;

    private Boolean stable;

    private Boolean opened;

    private Boolean wxbOpened;

    private Boolean wyylOpened;

    private Boolean wlttOpened;

    private Boolean wybdOpened;

    private Date gmtCreate;

    private Date gmtModified;

    /**
     * 起始位置
     */
    private Integer first;

    /**
     * 偏移量
     */
    private Integer offset;

    /**
     * 广告位置配置
     */
    private SlotPositionConfig slotPositionConfig;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(Integer positionCode) {
        this.positionCode = positionCode;
    }

    public String getPositionDesc() {
        return positionDesc;
    }

    public void setPositionDesc(String positionDesc) {
        this.positionDesc = positionDesc;
    }

    public Boolean getStable() {
        return stable;
    }

    public void setStable(Boolean stable) {
        this.stable = stable;
    }

    public Boolean getOpened() {
        return opened;
    }

    public void setOpened(Boolean opened) {
        this.opened = opened;
    }

    public Boolean getWxbOpened() {
        return wxbOpened;
    }

    public void setWxbOpened(Boolean wxbOpened) {
        this.wxbOpened = wxbOpened;
    }

    public Boolean getWyylOpened() {
        return wyylOpened;
    }

    public void setWyylOpened(Boolean wyylOpened) {
        this.wyylOpened = wyylOpened;
    }

    public Boolean getWlttOpened() {
        return wlttOpened;
    }

    public void setWlttOpened(Boolean wlttOpened) {
        this.wlttOpened = wlttOpened;
    }

    public Boolean getWybdOpened() {
        return wybdOpened;
    }

    public void setWybdOpened(Boolean wybdOpened) {
        this.wybdOpened = wybdOpened;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public SlotPositionConfig getSlotPositionConfig() {
        return slotPositionConfig;
    }

    public void setSlotPositionConfig(SlotPositionConfig slotPositionConfig) {
        this.slotPositionConfig = slotPositionConfig;
    }

    public Integer getFirst() {
        return first;
    }

    public void setFirst(Integer first) {
        this.first = first;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }
}
